@@ -38,6 +38,10 @@ impl Parser {
         self.inner.last()
     }
 
+    pub fn contains(&self, arg: &str) -> bool {
+        self.get(arg).is_some()
+    }
+
     pub fn len(&self) -> usize {
         self.inner.len()
     }
